@@ -698,12 +698,33 @@ mod tests {
         assert_rem("5e60", "3", "2");
         assert_rem("5e60", "300", "200");
         assert_rem("5e76", "3", "2");
-        assert_rem("5e77", "3", "2e39");
+        assert_rem("5e77", "3", "2");
         assert_rem("5e-42", "3e-84", "2e-84");
-        assert_rem("5e125", "3e-130", "2e87");
-        assert_rem("4e125", "3e-130", "1e87");
-        assert_rem("99999999999999999999999999999999999999e80", "7e-130", "2e42");
+        assert_rem("5e125", "3e-130", "2e-130");
+        assert_rem("4e125", "3e-130", "1e-130");
+        assert_rem("99999999999999999999999999999999999999e80", "7e-130", "1e-130");
         assert_rem("3", "5e42", "3");
+        assert_rem("1e10", "9223", "8365");
+        assert_rem("1e20", "9223", "7547");
+        assert_rem("1e30", "9223", "8443");
+        assert_rem("1e40", "9223", "5184");
+        assert_rem("1e50", "9223", "6837");
+        assert_rem("1e60", "9223", "8905");
+        assert_rem("1e70", "9223", "5377");
+        assert_rem("1e80", "9223", "7257");
+        assert_rem("1e90", "9223", "8242");
+        assert_rem("1e100", "9223", "2405");
+        assert_rem("1e110", "9223", "2462");
+        assert_rem("1e120", "9223", "8894");
+        assert_rem("1e125", "9223", "7664");
+        assert_rem("1.234172907e125", "9223", "5190");
+        assert_rem("333.456", "7", "4.456");
+        assert_rem("333.456", "7.7", "2.356");
+        assert_rem("333.456", "7.7654", "7.3092");
+        assert_rem("323", "7.7654", "4.6186");
+        assert_rem("0.0003456", "0.00000000234", "7.2e-10");
+        assert_rem("0.3456", "9.234e-130", "2.484e-130");
+        assert_rem("0.0003456", "0.234", "0.0003456");
     }
 
     #[test]
